==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/read.pfizer.Pivot.R <==
read.pfizer.Pivot <- function(file, verbose=TRUE)
  {
    ## line one of the header
    ## (only GeneNames are present in this row)
    header1 <- scan(file, what="", nlines=1, sep=",", quiet=TRUE)
    nonempty1 <- (header1 > " ") & (!is.na(header1))
    
    ## line two of the header
    ## Column Names are in this row
    header2 <- scan(file, what="", nlines=1, sep=",", skip=1, quiet=TRUE)
    nonempty2 <- (header2 > " ") & (!is.na(header1))

    ## drop trailing blanks 
    header1 <- header1[nonempty2]
    header2 <- header2[nonempty2]
    nonempty1 <- nonempty1[nonempty2]

    geneNames <- header1[nonempty1]
    colNames <- c("Donor ID", header2[-1])

    genotypeCols <-  which(nonempty1)
    phenotypeCols <- which(!nonempty1)[-c(2:3)]
    studyCols <- c(2,3)


    # now for the body of the data
    fileData <- scan(file, what="", skip=2, sep=",", quiet=TRUE)
    fileData <- matrix(fileData, ncol=length(header2), byrow=TRUE)
    colnames(fileData) <- colNames
    rownames(fileData) <- fileData[,1]

    if(verbose)
      {
        nGenes <- length(unique(geneNames))
        nmarkers <- length(genotypeCols)-1
        nSamples <- nrow(fileData)


        cat(
            "\n",
            "Read ", 2+nrow(fileData), " lines containing ",
            nmarkers, " Markers from ",
            nGenes,   " Genes on ",
            nSamples, " Samples.\n\n",
            sep=""
            )
      }


    genotypeInfo <- as.data.frame(fileData[,genotypeCols])
    phenotypeInfo <- as.data.frame(fileData[,phenotypeCols])
    rownames(genotypeInfo) <- rownames(genotypeInfo) <- fileData[,1]

    markerInfo <- data.frame(Gene=header1[nonempty1],
                             Marker=header2[nonempty1])
    markerInfo$Name <- paste(markerInfo$Gene,
                             markerInfo$Marker,
                             sep=":")
    rownames(markerInfo) <- markerInfo$Name

    studyInfo <- as.list(fileData[1,studyCols])
    
    
    retval <- list(
                   genotypeInfo = genotypeInfo,
                   phenotypeInfo = phenotypeInfo,
                   markerInfo= markerInfo,
                   studyInfo=studyInfo
                   )
                                  
    retval
  }

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/read.pfizer.Pivot.R <==
read.pfizer.Pivot <- function(file, verbose=TRUE)
  {
    ## line one of the header
    ## (only GeneNames are present in this row)
    header1 <- scan(file, what="", nlines=1, sep=",", quiet=TRUE)
    nonempty1 <- (header1 > " ") & (!is.na(header1))
    
    ## line two of the header
    ## Column Names are in this row
    header2 <- scan(file, what="", nlines=1, sep=",", skip=1, quiet=TRUE)
    nonempty2 <- (header2 > " ") & (!is.na(header1))

    ## drop trailing blanks 
    header1 <- header1[nonempty2]
    header2 <- header2[nonempty2]
    nonempty1 <- nonempty1[nonempty2]

    geneNames <- header1[nonempty1]
    colNames <- c("Donor ID", header2[-1])

    genotypeCols <-  which(nonempty1)
    phenotypeCols <- which(!nonempty1)[-c(2:3)]
    studyCols <- c(2,3)


    # now for the body of the data
    fileData <- scan(file, what="", skip=2, sep=",", quiet=TRUE)
    fileData <- matrix(fileData, ncol=length(header2), byrow=TRUE)
    colnames(fileData) <- colNames
    rownames(fileData) <- fileData[,1]

    if(verbose)
      {
        nGenes <- length(unique(geneNames))
        nMarkers <- length(genotypeCols)-1
        nSamples <- nrow(fileData)


        cat(
            "\n",
            "Read ", 2+nrow(fileData), " lines containing ",
            nMarkers, " Markers from ",
            nGenes,   " Genes on ",
            nSamples, " Samples.\n\n",
            sep=""
            )
      }


    genotypeInfo <- as.data.frame(fileData[,genotypeCols,drop=FALSE])
    phenotypeInfo <- as.data.frame(fileData[,phenotypeCols,drop=FALSE])
    rownames(genotypeInfo) <- rownames(genotypeInfo) <- fileData[,1]

    markerInfo <- data.frame(Gene=header1[nonempty1],
                             Marker=header2[nonempty1])
    markerInfo$Name <- paste(markerInfo$Gene,
                             markerInfo$Marker,
                             sep=":")
    rownames(markerInfo) <- markerInfo$Name

    studyInfo <- as.list(fileData[1,studyCols])
    
    
    retval <- list(
                   genotypeInfo = genotypeInfo,
                   phenotypeInfo = phenotypeInfo,
                   markerInfo= markerInfo,
                   studyInfo=studyInfo
                   )
                                  
    retval
  }
